@@ -361,7 +361,12 @@ def tests(
             click.echo(tabulate(rows, header, tablefmt="github"))
 
             click.echo(
-                "\nRun `launchable inspect tests --test-session-id {}` to view uploaded test results".format(test_session_id))
+                "\nVisit https://app.launchableinc.com/organizations/{organization}/workspaces/{workspace}/test-sessions/{test_session_id} to view uploaded test results (or run `launchable inspect tests --test-session-id {test_session_id}`)"
+                .format(
+                    organization=org,
+                    workspace=workspace,
+                    test_session_id=test_session_id,
+                ))
 
     context.obj = RecordTests(dry_run=context.obj.dry_run)
 
